---
name: New sampler
about: Request the implementation of a new sampler.
title: ''
labels: ''
assignees: ''
---

<!--
Before suggesting a new sampler, please make sure this hasn't already been suggested by searching through the past issues and the PR tracker.
-->

### Presentation of the new sampler

<!--
Assume that we know nothing about this sampler. Please give us as much information as possible so we can judge it fairly. That includes (but is not limited to):
- Academic article
- Blog posts
- Implementations
- Personnal experience with the algorithm
-->

### How does it compare to other algorithms in blackjax?

<!--
How does it compare in terms of
- Performance
- Generality
- Complexity
-->

### Where does it fit in blackjax

<!--
Please explain to us why you are suggesting this algorithm for integration with blackjax.
-->

### Are you willing to open a PR?

<!--
Tell us whether you are willing to implement the algorithm yourself, and if so if you can share a design plan.
-->

<!-- Thanks for contributing! -->
